@@ -139,15 +139,22 @@ class Cloudpan189:
             return False
         return '操作成功' in response['output']
 
-    def ls(self, remoteDirPath=''):
+    def ls(self, remoteDirPath='', showDetail=False):
         """
         获取指定目录里的文件列表，不指定路径则获取当前工作目录的文件列表
         :param remoteDirPath: 目录路径，文件夹绝对路径
         """
         if remoteDirPath == "":
-            response = self.cmd.executeCmdInWorkDirWithOutput(['./cloudpan189-go', 'ls'])
+            if showDetail:
+                response = self.cmd.executeCmdInWorkDirWithOutput(['./cloudpan189-go', 'll'])
+            else:
+                response = self.cmd.executeCmdInWorkDirWithOutput(['./cloudpan189-go', 'ls'])
         else:
-            response = self.cmd.executeCmdInWorkDirWithOutput(['./cloudpan189-go', 'ls', remoteDirPath])
+            if showDetail:
+                response = self.cmd.executeCmdInWorkDirWithOutput(['./cloudpan189-go', 'll', remoteDirPath])
+            else:
+                response = self.cmd.executeCmdInWorkDirWithOutput(['./cloudpan189-go', 'ls', remoteDirPath])
+
         # print(response['output'])
         if not response['success']:
             return False
@@ -158,7 +165,10 @@ class Cloudpan189:
         for line in lines:
             if line is None or len(line) == 0:
                 continue
-            fileInfo = self.__parseFileInfoLine(line)
+            if showDetail:
+                fileInfo = self.__parseDetailFileInfoLine(line)
+            else:
+                fileInfo = self.__parseFileInfoLine(line)
             if len(fileInfo) > 0:
                 fileList.append(fileInfo)
 
@@ -175,6 +185,9 @@ class Cloudpan189:
         # parse
         fileInfoLine = fileInfoLine.strip()
 
+        # #     文件大小         修改日期
+        #  0             -  2020-09-13 16:32:25  32534544/
+        #  1        2.06MB  2020-06-28 18:13:58  wx_camera_1592968329284.jpg
         pattern = re.compile(
             '^([0-9]+)\s+([0-9.mMkKgGtTbB-]+)\s+([1-9]\d{3}-(0[1-9]|1[0-2])-(0[1-9]|[1-2][0-9]|3[0-1])\s+(20|21|22|23|[0-1]\d):[0-5]\d:[0-5]\d)\s+')
         rs = pattern.findall(fileInfoLine)
@@ -194,6 +207,40 @@ class Cloudpan189:
         fileInfo['name'] = fileInfoLine[idx + len(fileInfo['createDate']):].strip()
         return fileInfo
 
+    def __parseDetailFileInfoLine(self, fileInfoLine=''):
+        fileInfo = {'name': '', 'fileId':'', 'fileMd5':'', 'fileRawSize':0, 'createDate': '', 'modifyDate': '', 'fileSize': '', 'isDir': False}
+        if fileInfoLine is None or len(fileInfoLine) == 0:
+            return {}
+
+        # parse
+        fileInfoLine = fileInfoLine.strip()
+
+        # #        FILE ID        文件大小               文件MD5               文件大小(原始)       创建日期                修改日期              文件(目录)
+        # 0  21472211458415815  5.97KB      4CF75F25920405A3A5DBD92452B76761  6111            2020-09-10 22:36:41  2020-09-10 22:36:41        192.tpp
+        # 1  91301311206680713  -           -                                 -               2020-08-24 21:20:08  2020-08-31 22:21:43        我的项目/
+        pattern = re.compile('^([0-9]+)\s+([a-zA-Z0-9-]+)\s+([0-9.mMkKgGtTbB-]+)\s+([a-zA-Z0-9-]+)\s+([0-9-]+)\s+([1-9]\d{3}-(0[1-9]|1[0-2])-(0[1-9]|[1-2][0-9]|3[0-1])\s+(20|21|22|23|[0-1]\d):[0-5]\d:[0-5]\d)\s+([1-9]\d{3}-(0[1-9]|1[0-2])-(0[1-9]|[1-2][0-9]|3[0-1])\s+(20|21|22|23|[0-1]\d):[0-5]\d:[0-5]\d)\s+')
+        rs = pattern.findall(fileInfoLine)
+        if len(rs) == 0:
+            return {}
+
+        tupleData = rs[0]
+        fileInfo['fileId'] = tupleData[1]
+        fileInfo['fileSize'] = tupleData[2]
+        if fileInfo['fileSize'] == '-':
+            fileInfo['isDir'] = True
+        else:
+            fileInfo['fileMd5'] = tupleData[3]
+            fileInfo['fileRawSize'] = tupleData[4]
+        fileInfo['createDate'] = tupleData[5]
+        fileInfo['modifyDate'] = tupleData[8]
+
+        # name
+        idx = fileInfoLine.find(fileInfo['createDate'])
+        if idx <= 0:
+            return {}
+        fileInfo['name'] = fileInfoLine[idx + len(fileInfo['createDate']):].strip()
+        return fileInfo
+
     def upload(self, localPath, remoteDirPath, overwrite=False):
         """
         上传文件或目录
@@ -242,3 +289,14 @@ class Cloudpan189:
         if '获取路径信息错误, 获取文件/目录的元信息, 遇到错误, 远端服务器返回错误' in response['output']:
             return False
         return '下载完成, 保存位置' in response['output'] or '文件已经存在' in response['output']
+
+    def sign(self):
+        """
+        签到
+        :return: 成功返回True
+        """
+        response = self.cmd.executeCmdInWorkDirWithOutput(['./cloudpan189-go', 'sign'])
+        if not response['success']:
+            return False
+        print(response)
+        return '签到成功' in response['output'] or '今日已签到' in response['output']
